@@ -60,6 +60,37 @@ class Test(unittest.TestCase):
         self.assertEqual(ret, expected)
         self.assertEqual(cpp_comment_format.format(ret, style="javadoc", doxygen="\\"), expected)
 
+    def test_mixed_style(self):
+        """ """
+
+        text = r"""
+    /**
+    This is a docstring.
+
+    \param a This is a parameter.
+    \return This is a return value.
+    */
+    int foo(int a) {
+        /* with a comment */
+    }
+        """
+
+        expected = """
+    /**
+     * This is a docstring.
+     *
+     * @param a This is a parameter.
+     * @return This is a return value.
+     */
+    int foo(int a) {
+        /* with a comment */
+    }
+        """
+
+        ret = cpp_comment_format.format(text, style="javadoc", doxygen="@")
+        self.assertEqual(ret, expected)
+        self.assertEqual(cpp_comment_format.format(ret, style="javadoc", doxygen="@"), expected)
+
 
 if __name__ == "__main__":
 
